Quantus CLI Library
This library provides the core functionality for interacting with the Quantus Network. It can be used as a dependency in other Rust projects that need to interact with the Quantus blockchain.
Re-exports
pub use error::QuantusError as Error;pub use error::Result;pub use chain::client::ChainConfig;pub use chain::client::QuantusClient;pub use cli::send::batch_transfer;pub use cli::send::format_balance_with_symbol;pub use cli::send::get_balance;pub use cli::send::transfer;pub use cli::send::transfer_with_nonce;pub use qp_dilithium_crypto;
Modules
- chain
- cli
- config
- Configuration management module
- error
- log
- Quantus CLI Logging Module
- subsquid
- Subsquid indexer client module for privacy-preserving queries.
- wallet
Macros
Structs
- Account
Id32 - An opaque 32-byte cryptographic identifier.
Enums
- Multi
Address - A multi-format address wrapper for on-chain accounts.