pub struct StorageApi;Implementations
Sourceimpl StorageApi
impl StorageApi
Sourcepub fn member_count_iter(&self) -> StaticAddress<(), MemberCount, (), Yes, Yes>
pub fn member_count_iter(&self) -> StaticAddress<(), MemberCount, (), Yes, Yes>
The number of members in the collective who have at least the rank according to the index of the vec.
Sourcepub fn member_count(
&self,
_0: Param0,
) -> StaticAddress<StaticStorageKey<Param0>, MemberCount, Yes, Yes, ()>
pub fn member_count( &self, _0: Param0, ) -> StaticAddress<StaticStorageKey<Param0>, MemberCount, Yes, Yes, ()>
The number of members in the collective who have at least the rank according to the index of the vec.
Sourcepub fn members_iter(&self) -> StaticAddress<(), Members, (), (), Yes>
pub fn members_iter(&self) -> StaticAddress<(), Members, (), (), Yes>
The current members of the collective.
Sourcepub fn members(
&self,
_0: Param0,
) -> StaticAddress<StaticStorageKey<Param0>, Members, Yes, (), ()>
pub fn members( &self, _0: Param0, ) -> StaticAddress<StaticStorageKey<Param0>, Members, Yes, (), ()>
The current members of the collective.
Sourcepub fn id_to_index_iter(&self) -> StaticAddress<(), IdToIndex, (), (), Yes>
pub fn id_to_index_iter(&self) -> StaticAddress<(), IdToIndex, (), (), Yes>
The index of each ranks’s member into the group of members who have at least that rank.
Sourcepub fn id_to_index_iter1(
&self,
_0: Param0,
) -> StaticAddress<StaticStorageKey<Param0>, IdToIndex, (), (), Yes>
pub fn id_to_index_iter1( &self, _0: Param0, ) -> StaticAddress<StaticStorageKey<Param0>, IdToIndex, (), (), Yes>
The index of each ranks’s member into the group of members who have at least that rank.
Sourcepub fn id_to_index(
&self,
_0: Param0,
_1: Param1,
) -> StaticAddress<(StaticStorageKey<Param0>, StaticStorageKey<Param1>), IdToIndex, Yes, (), ()>
pub fn id_to_index( &self, _0: Param0, _1: Param1, ) -> StaticAddress<(StaticStorageKey<Param0>, StaticStorageKey<Param1>), IdToIndex, Yes, (), ()>
The index of each ranks’s member into the group of members who have at least that rank.
Sourcepub fn index_to_id_iter(&self) -> StaticAddress<(), IndexToId, (), (), Yes>
pub fn index_to_id_iter(&self) -> StaticAddress<(), IndexToId, (), (), Yes>
The members in the collective by index. All indices in the range 0..MemberCount will
return Some, however a member’s index is not guaranteed to remain unchanged over time.
Sourcepub fn index_to_id_iter1(
&self,
_0: Param0,
) -> StaticAddress<StaticStorageKey<Param0>, IndexToId, (), (), Yes>
pub fn index_to_id_iter1( &self, _0: Param0, ) -> StaticAddress<StaticStorageKey<Param0>, IndexToId, (), (), Yes>
The members in the collective by index. All indices in the range 0..MemberCount will
return Some, however a member’s index is not guaranteed to remain unchanged over time.
Sourcepub fn index_to_id(
&self,
_0: Param0,
_1: Param1,
) -> StaticAddress<(StaticStorageKey<Param0>, StaticStorageKey<Param1>), IndexToId, Yes, (), ()>
pub fn index_to_id( &self, _0: Param0, _1: Param1, ) -> StaticAddress<(StaticStorageKey<Param0>, StaticStorageKey<Param1>), IndexToId, Yes, (), ()>
The members in the collective by index. All indices in the range 0..MemberCount will
return Some, however a member’s index is not guaranteed to remain unchanged over time.
Sourcepub fn voting_iter(&self) -> StaticAddress<(), Voting, (), (), Yes>
pub fn voting_iter(&self) -> StaticAddress<(), Voting, (), (), Yes>
Votes on a given proposal, if it is ongoing.
Sourcepub fn voting_iter1(
&self,
_0: Param0,
) -> StaticAddress<StaticStorageKey<Param0>, Voting, (), (), Yes>
pub fn voting_iter1( &self, _0: Param0, ) -> StaticAddress<StaticStorageKey<Param0>, Voting, (), (), Yes>
Votes on a given proposal, if it is ongoing.
Sourcepub fn voting(
&self,
_0: Param0,
_1: Param1,
) -> StaticAddress<(StaticStorageKey<Param0>, StaticStorageKey<Param1>), Voting, Yes, (), ()>
pub fn voting( &self, _0: Param0, _1: Param1, ) -> StaticAddress<(StaticStorageKey<Param0>, StaticStorageKey<Param1>), Voting, Yes, (), ()>
Votes on a given proposal, if it is ongoing.
pub fn voting_cleanup_iter( &self, ) -> StaticAddress<(), VotingCleanup, (), (), Yes>
pub fn voting_cleanup( &self, _0: Param0, ) -> StaticAddress<StaticStorageKey<Param0>, VotingCleanup, Yes, (), ()>