pub async fn is_member(
quantus_client: &QuantusClient,
address: &str,
) -> Result<bool>Expand description
Check if an address is a member of the Tech Collective
pub async fn is_member(
quantus_client: &QuantusClient,
address: &str,
) -> Result<bool>Check if an address is a member of the Tech Collective