pub enum WormholeCommands {
Address {
secret: String,
},
Prove {
secret: String,
amount: u128,
exit_account: String,
block: String,
transfer_count: u64,
funding_account: String,
output: String,
},
Aggregate {
proofs: Vec<String>,
output: String,
},
VerifyAggregated {
proof: String,
},
ParseProof {
proof: String,
aggregated: bool,
verify: bool,
},
Multiround {
num_proofs: usize,
rounds: usize,
amount: f64,
wallet: String,
password: Option<String>,
password_file: Option<String>,
keep_files: bool,
output_dir: String,
dry_run: bool,
},
Dissolve {
amount: f64,
target_size: f64,
wallet: String,
password: Option<String>,
password_file: Option<String>,
keep_files: bool,
output_dir: String,
},
Fuzz {
wallet: String,
password: Option<String>,
password_file: Option<String>,
amount: f64,
},
}Variants
Address
Derive the unspendable wormhole address from a secret
Prove
Generate a wormhole proof from an existing transfer
Fields
Aggregate
Aggregate multiple wormhole proofs into a single proof
Fields
VerifyAggregated
Verify an aggregated wormhole proof on-chain
ParseProof
Parse and display the contents of a proof file (for debugging)
Fields
Multiround
Run a multi-round wormhole test: wallet -> wormhole -> … -> wallet
Fields
Dissolve
Dissolve a large wormhole deposit into many small outputs for better privacy.
Creates a tree of wormhole transactions: each layer splits outputs into two, doubling the number of outputs until all are below the target size. This moves funds from a high-amount bucket (few deposits, low privacy score) into the low-amount bucket (many miner rewards, high privacy score).
Fields
Fuzz
Fuzz test the leaf verification by attempting invalid proofs