Module subsquid

Module subsquid 

Subsquid indexer client module for privacy-preserving queries.

This module provides a client for querying the Subsquid indexer using hash prefix queries, which allows clients to retrieve their transactions without revealing their exact addresses to the indexer.

Structs

GraphQLError
GraphQL error.
GraphQLErrorLocation
GraphQL error location.
GraphQLResponse
GraphQL response wrapper.
SubsquidClient
Client for querying the Subsquid indexer.
Transfer
A transfer as returned by the Subsquid indexer.
TransferQueryParams
Query parameters for transfer prefix queries.
TransfersByPrefixResult
Result from a prefix query.

Functions

compute_address_hash
Compute blake3 hash of raw address bytes and return as hex string.
get_hash_prefix
Get a prefix of the specified length from a hash.