compute_address_hash

Function compute_address_hash 

pub fn compute_address_hash(raw_address: &[u8; 32]) -> String
Compute blake3 hash of raw address bytes and return as hex string.

This matches the hash computation done by the Subsquid indexer.

Arguments

  • raw_address - The raw 32-byte account ID

Returns

The blake3 hash as a 64-character hex string