Subsquid indexer client module for privacy-preserving queries.
This module provides a client for querying the Subsquid indexer using hash prefix queries, which allows clients to retrieve their transactions without revealing their exact addresses to the indexer.
Structs
- GraphQL
Error - GraphQL error.
- GraphQL
Error Location - GraphQL error location.
- GraphQL
Response - GraphQL response wrapper.
- Subsquid
Client - Client for querying the Subsquid indexer.
- Transfer
- A transfer as returned by the Subsquid indexer.
- Transfer
Query Params - Query parameters for transfer prefix queries.
- Transfers
ByPrefix Result - Result from a prefix query.
Functions
- compute_
address_ hash - Compute blake3 hash of raw address bytes and return as hex string.
- get_
hash_ prefix - Get a prefix of the specified length from a hash.